#!/bin/sh

export LC_ALL=POSIX

a= . install2-init-functions

if grep -E '[[:space:]]swap[[:space:]]+swap[[:space:]]' $destdir/etc/fstab | grep -qv '^#' ; then
    # swap already present
    exit 0
fi

SWAP_MUL=1 # swap size multiplicator
SWAP_MAX=$[16*1048576]

# swap ~= RAM (but not more than $SWAP_MAX)
mem="`grep MemTotal /proc/meminfo | sed 's/[^0-9]//g'`"
[ -n "$mem" ] || mem=1048576
swap_size="$[$mem*$SWAP_MUL]"
[ "$swap_size" -gt "$SWAP_MAX" ] && swap_size="$SWAP_MAX"
swap_size=$[$swap_size*21/20] # add 5% to fit hibernation

# decrease swap under virtualization
if lspci -n | grep -qE '(1013:00b8)|(80ee:beef)|(15ad:0405)|(1af4:100)' ; then
    swap_size=131072 # 128M
fi

swap_file="swap"
swap_dir="/"
swap_destdir="$destdir"
swap_destpath="$destdir/$swap_file"

[ -e "$swap_destpath" ] && exit 0 ||:
truncate -s 0 $swap_destpath
if chattr +C $swap_destpath 2>/dev/null ; then
    # success check for COW
    # fail for snapshots with active swap; maybe another partition
    rm -f $swap_destpath
    swap_dir="/home"
    swap_destdir="$destdir$swap_dir"
    swap_destpath="$destdir$swap_dir/$swap_file"
    truncate -s 0 $swap_destpath
    chattr +C $swap_destpath 2>/dev/null ||: # nothing to do for now
fi

freespace_size=`df --sync -Pk $swap_destdir | tail -n 1 | sed -E 's|[[:space:]]+| |g' | cut -d\  -f 4`
[ -n "$freespace_size" ] || freespace_size=0
# decrease swap when low free space
if [ "$[$swap_size*2]" -gt "$freespace_size" ] ; then
    swap_size="$[$freespace_size/3]"
fi

[ "$swap_size" -gt "1000" ] || exit 0
fallocate -l "${swap_size}K" $swap_destpath || exit 0
chown root:root $swap_destpath
chmod 0600 $swap_destpath
mkswap $swap_destpath || exit 0

swap_path=`echo "$swap_dir/$swap_file" | sed 's|//*|/|g'`
echo "# installer-feature-swapfile" >> $destdir/etc/fstab
echo "$swap_path	swap	swap	defaults	0	0" >> $destdir/etc/fstab
